@@ -1,4 +1,4 @@
-from hdsr_wis_config_reader.idmappings.columns import IdMapColumnChoices
+from hdsr_wis_config_reader.idmappings.columns import IdMapCols
 from typing import List
 
 import logging
@@ -20,25 +20,19 @@ class IdMappingDataframe(pd.DataFrame):
 
     @classmethod
     def __get_query(cls, **kwargs) -> str:
-        dynamic_query = " & ".join(
-            [f"{key}=='{value}'" for key, value in kwargs.items() if value]
-        )
+        dynamic_query = " & ".join([f"{key}=='{value}'" for key, value in kwargs.items() if value])
         return dynamic_query
 
     def get_filtered_df(
-        self,
-        ex_loc: str = None,
-        ex_par: str = None,
-        int_loc: str = None,
-        int_par: str = None,
+        self, ex_loc: str = None, ex_par: str = None, int_loc: str = None, int_par: str = None,
     ) -> pd.DataFrame:
         """Filter dataframe rows based on ex_loc, ex_par, int_loc, int_par."""
         dynamic_query = self.__get_query(
             **{
-                IdMapColumnChoices.ex_loc.value: ex_loc,
-                IdMapColumnChoices.ex_par.value: ex_par,
-                IdMapColumnChoices.int_loc.value: int_loc,
-                IdMapColumnChoices.int_par.value: int_par,
+                IdMapCols.ex_loc: ex_loc,
+                IdMapCols.ex_par: ex_par,
+                IdMapCols.int_loc: int_loc,
+                IdMapCols.int_par: int_par,
             }
         )
         if not dynamic_query:
@@ -50,21 +44,17 @@ class IdMappingDataframe(pd.DataFrame):
     def get_filtered_column_values(
         self,
         make_result_unique: bool,
-        target_column: IdMapColumnChoices,
+        target_column: str,
         ex_loc: str = None,
         ex_par: str = None,
         int_loc: str = None,
         int_par: str = None,
     ) -> List[str]:
-        assert isinstance(target_column, IdMapColumnChoices)
-        filtered_df = self.get_filtered_df(
-            ex_loc=ex_loc, ex_par=ex_par, int_loc=int_loc, int_par=int_par
-        )
-        assert target_column.value in filtered_df.columns
+        assert target_column in IdMapCols.get_all(), f"target_column {target_column} must be in {IdMapCols.get_all()}"
+        filtered_df = self.get_filtered_df(ex_loc=ex_loc, ex_par=ex_par, int_loc=int_loc, int_par=int_par)
+        assert target_column in filtered_df.columns
         if filtered_df.empty:
             return []
-        column_values = filtered_df[target_column.value].to_list()
-        column_values = (
-            list(set(column_values)) if make_result_unique else column_values
-        )
+        column_values = filtered_df[target_column].to_list()
+        column_values = list(set(column_values)) if make_result_unique else column_values
         return sorted(column_values)
