@@ -13,9 +13,7 @@ logger = logging.getLogger(__name__)
 
 
 class LocationSetBase:
-    def __init__(
-        self, fews_config: FewsConfigReader = None, fews_config_path: Path = None
-    ):
+    def __init__(self, fews_config: FewsConfigReader = None, fews_config_path: Path = None):
         assert (fews_config and not fews_config_path) or (
             fews_config_path and not fews_config
         ), "use either path or config"
@@ -58,9 +56,7 @@ class LocationSetBase:
     def geo_df_original(self) -> gpd.GeoDataFrame:
         if self._geo_df_original is not None:
             return self._geo_df_original
-        self._geo_df_original = self.fews_config.get_locations(
-            location_set_key=self.fews_name
-        )
+        self._geo_df_original = self.fews_config.get_locations(location_set_key=self.fews_name)
         assert isinstance(self._geo_df_original, gpd.GeoDataFrame)
         return self._geo_df_original
 
@@ -78,14 +74,10 @@ class LocationSetBase:
             return self._general_location_sets_dict
         location_sets_file_path = self.fews_config.RegionConfigFiles["LocationSets"]
         location_sets_dict = XmlReader.xml_to_dict(xml_filepath=location_sets_file_path)
-        self._general_location_sets_dict = location_sets_dict["locationSets"][
-            "locationSet"
-        ]
+        self._general_location_sets_dict = location_sets_dict["locationSets"]["locationSet"]
         # ensure unique ids, e.g. 'OPVLWATER_HOOFDLOC', 'OPVLWATER_SUBLOC', 'RWZI', ..
         ids = [x["id"] for x in self._general_location_sets_dict]
-        assert len(set(ids)) == len(
-            ids
-        ), "we expected unique id's in RegionConfigFiles LocationSets"
+        assert len(set(ids)) == len(ids), "we expected unique id's in RegionConfigFiles LocationSets"
         return self._general_location_sets_dict
 
     @property
@@ -102,11 +94,7 @@ class LocationSetBase:
         """
         if self._csvfile_meta is not None:
             return self._csvfile_meta
-        csvfile_meta = [
-            loc_set
-            for loc_set in self.general_location_sets_dict
-            if loc_set["id"] == self.fews_name
-        ]
+        csvfile_meta = [loc_set for loc_set in self.general_location_sets_dict if loc_set["id"] == self.fews_name]
         assert len(csvfile_meta) == 1
         self._csvfile_meta = csvfile_meta[0]["csvFile"]
         return self._csvfile_meta
@@ -129,9 +117,7 @@ class LocationSetBase:
         assert all(
             [isinstance(attrib_file, dict) for attrib_file in attribute_files]
         ), "attribute_files must be list with dicts"
-        self._attrib_files = [
-            attrib_file for attrib_file in attribute_files if "attribute" in attrib_file
-        ]
+        self._attrib_files = [attrib_file for attrib_file in attribute_files if "attribute" in attrib_file]
         return self._attrib_files
 
     def get_validation_attributes(self, int_pars: List[str] = None) -> List[str]:
@@ -153,16 +139,11 @@ class LocationSetBase:
             get_validation_attributes(int_pars=None) returns: ['HR1_HMAX', 'HR1_HMIN', 'HR2_HMAX', 'HR2_HMIN']
         """
         if not int_pars:
-            logger.debug(
-                f"returning all validation parameters for locationset {self.name}"
-            )
+            logger.debug(f"returning all validation parameters for locationset {self.name}")
             int_pars = [rule["parameter"] for rule in self.validation_rules]
         result = []
         for rule in self.validation_rules:
-            if not any(
-                bool(re.match(pattern=rule["parameter"], string=int_par))
-                for int_par in int_pars
-            ):
+            if not any(bool(re.match(pattern=rule["parameter"], string=int_par)) for int_par in int_pars):
                 continue
             result.extend(rule["extreme_values"].values())
         return result
