@@ -1,6 +1,6 @@
 from hdsr_wis_config_reader import IdMappingCollection
 from hdsr_wis_config_reader.constants import WIS_CONFIG_TEST_DIR
-from hdsr_wis_config_reader.idmappings.columns import IdMapColumnChoices
+from hdsr_wis_config_reader.idmappings.columns import IdMapCols
 from hdsr_wis_config_reader.idmappings.files import IdMapChoices
 from hdsr_wis_config_reader.tests.fixtures import fews_config_local
 from hdsr_wis_config_reader.tests.helpers import is_equal_dataframes
@@ -54,15 +54,13 @@ def test_idmapping_opvl_water(fews_config_local):
     id_mappings = IdMappingCollection(fews_config=fews_config_local)
     assert id_mappings.idmap_opvl_water.shape == (6050, 6)
 
-    df_idmap_opvl_water = id_mappings.idmap_opvl_water.get_filtered_df(
-        int_loc="KW761001"
-    )
+    df_idmap_opvl_water = id_mappings.idmap_opvl_water.get_filtered_df(int_loc="KW761001")
     assert isinstance(df_idmap_opvl_water, pd.DataFrame)
     assert len(df_idmap_opvl_water) == 2
     assert is_equal_dataframes(expected_df=expected_df_a, test_df=df_idmap_opvl_water)
 
     ex_par_values = id_mappings.idmap_grondwater_caw.get_filtered_column_values(
-        make_result_unique=True, target_column=IdMapColumnChoices.ex_par,
+        make_result_unique=True, target_column=IdMapCols.ex_par,
     )
     assert ex_par_values == expected_ex_par_values
 
@@ -76,34 +74,22 @@ def test_read_idmap_oppvl(fews_config_local):
 
     # read without fews config
     oppvl_path1 = WIS_CONFIG_TEST_DIR / "IdMapFiles" / "IdOPVLWATER.xml"
-    df_oppvl_without_fews = IdMappingCollection.get_idmap_df_via_path(
-        file_path=oppvl_path1
-    )
+    df_oppvl_without_fews = IdMappingCollection.get_idmap_df_via_path(file_path=oppvl_path1)
     assert len(df_oppvl_without_fews) == 6050
 
     # read same idmap but now via fews config
     collection = IdMappingCollection(fews_config=fews_config_local)
-    df_oppvl_with_fews = collection.get_idmap_df_via_choice(
-        IdMapChoices.idmap_opvl_water
-    )
-    assert is_equal_dataframes(
-        expected_df=df_oppvl_without_fews, test_df=df_oppvl_with_fews
-    )
+    df_oppvl_with_fews = collection.get_idmap_df_via_choice(IdMapChoices.idmap_opvl_water)
+    assert is_equal_dataframes(expected_df=df_oppvl_without_fews, test_df=df_oppvl_with_fews)
 
 
 def test_read_idmap_oppvl_hymos(fews_config_local):
     # read without fews config
     oppvl_path1 = WIS_CONFIG_TEST_DIR / "IdMapFiles" / "IdOPVLWATER_HYMOS.xml"
-    df_oppvl_hymos_without_fews = IdMappingCollection.get_idmap_df_via_path(
-        file_path=oppvl_path1
-    )
+    df_oppvl_hymos_without_fews = IdMappingCollection.get_idmap_df_via_path(file_path=oppvl_path1)
     assert len(df_oppvl_hymos_without_fews) == 2360
 
     # read same idmap but now via fews config
     collection = IdMappingCollection(fews_config=fews_config_local)
-    df_oppvl_hymos_with_fews = collection.get_idmap_df_via_choice(
-        IdMapChoices.idmap_opvl_water_hymos
-    )
-    assert is_equal_dataframes(
-        expected_df=df_oppvl_hymos_without_fews, test_df=df_oppvl_hymos_with_fews
-    )
+    df_oppvl_hymos_with_fews = collection.get_idmap_df_via_choice(IdMapChoices.idmap_opvl_water_hymos)
+    assert is_equal_dataframes(expected_df=df_oppvl_hymos_without_fews, test_df=df_oppvl_hymos_with_fews)
